@@ -7,7 +7,7 @@
 #  define VTKIOVIDEO_NO_EXPORT
 #else
 #  ifndef VTKIOVIDEO_EXPORT
-#    ifdef vtkIOVideo_EXPORTS
+#    ifdef IOVideo_EXPORTS
         /* We are building this library */
 #      define VTKIOVIDEO_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKIOVIDEO_DEPRECATED
 #  define VTKIOVIDEO_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOVIDEO_DEPRECATED_EXPORT VTKIOVIDEO_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOVIDEO_DEPRECATED_NO_EXPORT VTKIOVIDEO_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOVIDEO_NO_DEPRECATED
+#ifndef VTKIOVIDEO_DEPRECATED_EXPORT
+#  define VTKIOVIDEO_DEPRECATED_EXPORT VTKIOVIDEO_EXPORT VTKIOVIDEO_DEPRECATED
 #endif
 
-
-
+#ifndef VTKIOVIDEO_DEPRECATED_NO_EXPORT
+#  define VTKIOVIDEO_DEPRECATED_NO_EXPORT VTKIOVIDEO_NO_EXPORT VTKIOVIDEO_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOVIDEO_NO_DEPRECATED
+#    define VTKIOVIDEO_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkIOVideoModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKIOVIDEO_EXPORT_H */
