@@ -7,7 +7,7 @@
 #  define VTKIOXDMF2_NO_EXPORT
 #else
 #  ifndef VTKIOXDMF2_EXPORT
-#    ifdef vtkIOXdmf2_EXPORTS
+#    ifdef IOXdmf2_EXPORTS
         /* We are building this library */
 #      define VTKIOXDMF2_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,25 @@
 
 #ifndef VTKIOXDMF2_DEPRECATED
 #  define VTKIOXDMF2_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOXDMF2_DEPRECATED_EXPORT VTKIOXDMF2_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOXDMF2_DEPRECATED_NO_EXPORT VTKIOXDMF2_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOXDMF2_NO_DEPRECATED
+#ifndef VTKIOXDMF2_DEPRECATED_EXPORT
+#  define VTKIOXDMF2_DEPRECATED_EXPORT VTKIOXDMF2_EXPORT VTKIOXDMF2_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersExtractionModule.h"
-#include "vtkIOXMLModule.h"
-
+#ifndef VTKIOXDMF2_DEPRECATED_NO_EXPORT
+#  define VTKIOXDMF2_DEPRECATED_NO_EXPORT VTKIOXDMF2_NO_EXPORT VTKIOXDMF2_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOXDMF2_NO_DEPRECATED
+#    define VTKIOXDMF2_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkIOXdmf2Module.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKIOXDMF2_EXPORT_H */
