@@ -39,4 +39,9 @@
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkRenderingFFMPEGOpenGL2Module.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKRENDERINGFFMPEGOPENGL2_EXPORT_H */
