@@ -7,7 +7,7 @@
 #  define VTKVIEWSCORE_NO_EXPORT
 #else
 #  ifndef VTKVIEWSCORE_EXPORT
-#    ifdef vtkViewsCore_EXPORTS
+#    ifdef ViewsCore_EXPORTS
         /* We are building this library */
 #      define VTKVIEWSCORE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,25 @@
 
 #ifndef VTKVIEWSCORE_DEPRECATED
 #  define VTKVIEWSCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKVIEWSCORE_DEPRECATED_EXPORT VTKVIEWSCORE_EXPORT __attribute__ ((__deprecated__))
-#  define VTKVIEWSCORE_DEPRECATED_NO_EXPORT VTKVIEWSCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKVIEWSCORE_NO_DEPRECATED
+#ifndef VTKVIEWSCORE_DEPRECATED_EXPORT
+#  define VTKVIEWSCORE_DEPRECATED_EXPORT VTKVIEWSCORE_EXPORT VTKVIEWSCORE_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkInteractionWidgetsModule.h"
-
+#ifndef VTKVIEWSCORE_DEPRECATED_NO_EXPORT
+#  define VTKVIEWSCORE_DEPRECATED_NO_EXPORT VTKVIEWSCORE_NO_EXPORT VTKVIEWSCORE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKVIEWSCORE_NO_DEPRECATED
+#    define VTKVIEWSCORE_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkViewsCoreModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKVIEWSCORE_EXPORT_H */
